=====
Usage
=====

The primary use of Boreal is in the context of Python/Jupyter notebooks.
An example notebook is provided at (also part of the source code release): 

https://github.com/gtzan/boreal/blob/main/boreal/audio_widgets_notebook.ipynb

One can also explicitly start the Bokeh application as follows::
  
  bokeh serve --show audio_widgets --args beatles.wav pyaudio spectrum


 
